@@ -29,7 +29,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: exifutil.c,v 1.24 2003/08/08 22:31:32 ejohnst Exp $
+ * $Id: exifutil.c,v 1.26 2004/11/06 18:36:46 ejohnst Exp $
  */
 
 /*
@@ -170,6 +170,35 @@ finddescr(struct descrip *table, u_int16_t val)
 }
 
 
+/*
+ * Lookup and append description for a value.
+ * Doesn't do anything if the value is unknown; first adds ", " if dest
+ * contains a value; returns number of bytes added.  len is total size
+ * of destination buffer.
+ */
+int
+catdescr(char *c, struct descrip *table, u_int16_t val, int len)
+{
+	int i, l;
+
+	l = 0;
+	len -= 1;
+	c[len] = '\0';
+
+	for (i = 0; table[i].val != -1 && table[i].val != val; i++);
+	if (table[i].val == -1)
+		return (0);
+
+	if (strlen(c)) {
+		strncat(c, ", ", len - strlen(c));
+		l += 2;
+	}
+	strncat(c, table[i].descr, len - strlen(c));
+	l += strlen(table[i].descr);
+	return (l);
+}
+
+
 /*
  * Lookup a property entry belonging to a particular set of tags.
  */
@@ -364,6 +393,11 @@ readifds(u_int32_t offset, struct exiftag *tagset, struct tiffmeta *md)
 {
 	struct ifd *firstifd, *curifd;
 
+	/*
+	 * XXX Note: we really should be checking to see if this IFD
+	 * has already been visited...
+	 */
+	
 	/* Fetch our first one. */
 
 	offset = readifd(offset, &firstifd, tagset, md);
